==> Pyrogram-0.12.0-py3-none-any.whl: pyrogram/api/types/keyboard_button_game.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class KeyboardButtonGame(Object):
    """Attributes:
        ID: ``0x50f41ccf``

    Args:
        text: ``str``
    """

    __slots__ = ["text"]

    ID = 0x50f41ccf
    QUALNAME = "KeyboardButtonGame"

    def __init__(self, *, text: str):
        self.text = text  # string

    @staticmethod
    def read(b: BytesIO, *args) -> "KeyboardButtonGame":
        # No flags
        
        text = String.read(b)
        
        return KeyboardButtonGame(text=text)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(String(self.text))
        
        return b.getvalue()

==> Pyrogram-0.13.0-py3-none-any.whl: pyrogram/api/types/keyboard_button_game.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class KeyboardButtonGame(Object):
    """Attributes:
        ID: ``0x50f41ccf``

    Parameters:
        text: ``str``
    """

    __slots__ = ["text"]

    ID = 0x50f41ccf
    QUALNAME = "types.KeyboardButtonGame"

    def __init__(self, *, text: str):
        self.text = text  # string

    @staticmethod
    def read(b: BytesIO, *args) -> "KeyboardButtonGame":
        # No flags
        
        text = String.read(b)
        
        return KeyboardButtonGame(text=text)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(String(self.text))
        
        return b.getvalue()
